#include "servoframe.h"
#include "ui_servoframe.h"

servoFrame::servoFrame(QWidget *parent) :
    QFrame(parent),
    m_ui(new Ui::servoFrame)
{
    m_ui->setupUi(this);
    m_ui->selectedBox->setChecked(true);
    m_ui->selectedBox->setChecked(false);
}

servoFrame::~servoFrame()
{
    delete m_ui;
}

void servoFrame::changeEvent(QEvent *e)
{
    QFrame::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        m_ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

QString servoFrame::id()
{
    return m_ui->nameEdit->text();
}

int servoFrame::port()
{
    return m_ui->portSpin->value();
}

int servoFrame::pos()
{
    return m_ui->positionSpin->value();
}

void servoFrame::setId(QString id)
{
    m_ui->nameEdit->setText(id);
}

void servoFrame::setPort(int port)
{
    m_ui->portSpin->setValue(port);
}

void servoFrame::setPos(int pos)
{
    m_ui->positionSpin->setValue(pos);
}

bool servoFrame::selected()
{
    return m_ui->selectedBox->isChecked();
}

void servoFrame::setSelected(bool sel)
{
    return m_ui->selectedBox->setChecked(sel);
}

void servoFrame::on_positionSpin_valueChanged(int )
{
    emit onServoChange(this->id(), this);
}

void servoFrame::on_selectedBox_toggled(bool checked)
{
    m_ui->positionDial->setEnabled(checked);
    m_ui->positionSpin->setEnabled(checked);
    if(!checked)m_ui->positionDial->setValue(0);
    emit onServoChange(this->id(),this);
}


void servoFrame::on_nameEdit_textChanged(QString str)
{
    emit onServoChange(str,this);
}

QDomNode servoFrame::prepareXmlBlock(QDomDocument doc)
{
    QDomElement sf_xml = doc.createElement("servo");
    QDomElement id_xml = doc.createElement("id");
    QDomElement port_xml = doc.createElement("port");
    QDomElement pos_x_xml = doc.createElement("pos_x");
    QDomElement pos_y_xml = doc.createElement("pos_y");
    QDomText id_txt = doc.createTextNode(this->id());
    QDomText port_txt = doc.createTextNode(QString::number(this->port()));
    QDomText pos_x_txt = doc.createTextNode(QString::number(this->geometry().left()));
    QDomText pos_y_txt = doc.createTextNode(QString::number(this->geometry().top()));
    id_xml.appendChild(id_txt);
    port_xml.appendChild(port_txt);
    pos_x_xml.appendChild(pos_x_txt);
    pos_y_xml.appendChild(pos_y_txt);
    sf_xml.appendChild(id_xml);
    sf_xml.appendChild(port_xml);
    sf_xml.appendChild(pos_x_xml);
    sf_xml.appendChild(pos_y_xml);
    return sf_xml;
}

void servoFrame::setLocation(int x,int y)
{
    QRect r=this->geometry();
    r.setLeft(x);
    r.setTop(y);
    r.setWidth(120);
    r.setHeight(160);
    this->setGeometry(r);
}

void servoFrame::setLocation(QPoint p)
{
    this->setLocation(p.x(),p.y());
}

QString servoFrame::readXmlBlock(QDomNode node)
{
    if(node.childNodes().at(0).nodeName()!="id"){
        return "First child of some <servo> is not <id>!";
    }else if(node.childNodes().at(1).nodeName()!="port"){
        return "Second child of some <servo> is not <port>!";
    }else if(node.childNodes().at(2).nodeName()!="pos_x"){
        return "Third child of some <servo> is not <pos_x>!";
    }else if(node.childNodes().at(3).nodeName()!="pos_y"){
        return "Fourth child of some <servo> is not <pos_y>!";
    }else{
        this->setId(node.childNodes().at(0).childNodes().at(0).nodeValue());
        this->setPort(node.childNodes().at(1).childNodes().at(0).nodeValue().toInt());
        QRect r=this->geometry();
        int x=node.childNodes().at(2).childNodes().at(0).nodeValue().toInt();
        int y=node.childNodes().at(3).childNodes().at(0).nodeValue().toInt();
        this->setLocation(x,y);
        return "";
    };
}
